Documentation
¶
Overview ¶
Package otel handles the configuration and lifecycle of the opentelemetry-collector Its' purpose is to generate a resolver setting that incorporates multiple providers collector consumes otel/providers which consume otel/config
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Collector ¶
Collector is an interface that is satisfied by the otelcol.Collector struct. This allows us to wrap the opentelemetry collector and not necessarily run it ourselves.
func NewCollector ¶
func NewCollector(cfg CollectorCfg) (Collector, error)
NewCollector will create a new open-telemetry collector service and configuration based on the provided values.
type CollectorCfg ¶
type CollectorCfg struct {
ClientID string
ClientSecret string
ResourceID string
Client hcp.TelemetryClient
ForwarderEndpoint string
ExporterConfig *config.ExporterConfig
MetricsPort int
EnvoyPort int
BatchTimeout time.Duration
}
CollectorCfg is the configuration needed to start the collector.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package config manages helpers to generate opentelemetry-collector configuration.
|
Package config manages helpers to generate opentelemetry-collector configuration. |
|
helpers/exporters
Package exporters holds the type of exporters that consul telemetery supports
|
Package exporters holds the type of exporters that consul telemetery supports |
|
helpers/extensions
Package extensions holds the type of extensions that consul telemetery supports
|
Package extensions holds the type of extensions that consul telemetery supports |
|
helpers/processors
Package processors holds the type of processors that consul telemetery supports
|
Package processors holds the type of processors that consul telemetery supports |
|
helpers/receivers
Package receivers holds the type of receivers that consul telemetery supports
|
Package receivers holds the type of receivers that consul telemetery supports |
|
helpers/types
Package types is a place to store reused types amongst the helpers
|
Package types is a place to store reused types amongst the helpers |
|
Package providers contains shared configuration structs for both HCP and external configuration providers.
|
Package providers contains shared configuration structs for both HCP and external configuration providers. |
|
external
Package external provides a static confmap.Provider that returns static configuration
|
Package external provides a static confmap.Provider that returns static configuration |
|
hcp
Package hcp will retrieve configuration open-telemetry-collector configuration from HCP
|
Package hcp will retrieve configuration open-telemetry-collector configuration from HCP |
Click to show internal directories.
Click to hide internal directories.